@@ -6,13 +6,13 @@ import pydicom
 import numpy as np
 from pydicom.tag import Tag
 import SimpleITK as sitk
-from skimage import draw
 from skimage.measure import label, regionprops, find_contours
 from threading import Thread
 from multiprocessing import cpu_count
 from queue import *
 import pandas as pd
 import copy
+import cv2
 from .Viewer import plot_scroll_Image
 
 
@@ -58,9 +58,10 @@ def folder_worker(A):
             break
         else:
             dicom_adder = AddDicomToDictionary()
-            dicom_path, images_dictionary, rt_dictionary, rd_dictionary = item
+            dicom_path, images_dictionary, rt_dictionary, rd_dictionary, verbose = item
             try:
-                print('Loading from {}'.format(dicom_path))
+                if verbose:
+                    print('Loading from {}'.format(dicom_path))
                 dicom_adder.add_dicom_to_dictionary_from_path(dicom_path=dicom_path,
                                                               images_dictionary=images_dictionary,
                                                               rt_dictionary=rt_dictionary,
@@ -105,11 +106,24 @@ class PointOutputMakerClass(object):
                 self.contour_dict[i].append(np.asarray(contour))
 
 
-def poly2mask(vertex_row_coords, vertex_col_coords, shape):
-    fill_row_coords, fill_col_coords = draw.polygon(vertex_row_coords, vertex_col_coords, shape)
-    mask = np.zeros(shape, dtype=np.bool)
-    mask[fill_row_coords, fill_col_coords] = True
-    return mask
+def poly2mask(vertex_row_coords: np.array, vertex_col_coords: np.array,
+              shape: tuple) -> np.array:
+    """[converts polygon coordinates to filled boolean mask]
+
+    Args:
+        vertex_row_coords (np.array): [row image coordinates]
+        vertex_col_coords (np.array): [column image coordinates]
+        shape (tuple): [image dimensions]
+
+    Returns:
+        [np.array]: [filled boolean polygon mask with vertices at
+                     (row, col) coordinates]
+    """
+    xy_coords = np.array([vertex_col_coords, vertex_row_coords])
+    coords = np.expand_dims(xy_coords.T, 0)
+    mask = np.zeros(shape)
+    cv2.fillPoly(mask, coords, 1)
+    return np.array(mask, dtype=np.bool)
 
 
 def add_images_to_dictionary(images_dictionary, sitk_dicom_reader, path):
@@ -300,7 +314,8 @@ class DicomReaderWriter(object):
         """
         The goal of this is to combine image, rt, and dose dictionaries based on the SeriesInstanceUIDs
         """
-        print('Compiling dictionaries together...')
+        if self.verbose:
+            print('Compiling dictionaries together...')
         series_instance_uids = []
         for key, value in self.series_instances_dictionary.items():
             series_instance_uids.append(value['SeriesInstanceUID'])
@@ -428,9 +443,10 @@ class DicomReaderWriter(object):
                     lacking_rois.append(roi)
             if lacking_rois:
                 self.all_contours_exist = False
-                print('Lacking {} in index {}, location {}. Found {}'.format(lacking_rois, index,
-                                                                             self.series_instances_dictionary[index]
-                                                                             ['Image_Path'], self.rois_in_case))
+                if self.verbose:
+                    print('Lacking {} in index {}, location {}. Found {}'.format(lacking_rois, index,
+                                                                                 self.series_instances_dictionary[index]
+                                                                                 ['Image_Path'], self.rois_in_case))
             if index not in self.indexes_with_contours:
                 if self.all_contours_exist or not self.require_all_contours:
                     self.indexes_with_contours.append(index)  # Add the index that has the contours
@@ -489,7 +505,7 @@ class DicomReaderWriter(object):
                 t.start()
                 threads.append(t)
             for index, path in enumerate(paths_with_dicom):
-                item = [path, self.images_dictionary, self.rt_dictionary, self.rd_dictionary]
+                item = [path, self.images_dictionary, self.rt_dictionary, self.rd_dictionary, self.verbose]
                 q.put(item)
             for i in range(thread_count):
                 q.put(None)
